@@ -526,8 +526,7 @@ fn parse_opt<'a>(
     pat: &str,
     require_value: bool,
 ) -> Result<Option<Option<&'a str>>> {
-    if arg.starts_with(pat) {
-        let rem = &arg[pat.len()..];
+    if let Some(rem) = arg.strip_prefix(pat) {
         if rem.is_empty() {
             if require_value {
                 return Ok(Some(Some(args.next().ok_or_else(|| req_arg(pat, subcommand))?)));
@@ -537,8 +536,7 @@ fn parse_opt<'a>(
             } else {
                 Ok(Some(args.next()))
             }
-        } else if rem.starts_with('=') {
-            let mut val = &rem[1..];
+        } else if let Some(mut val) = rem.strip_prefix('=') {
             if val.starts_with('\'') && val.ends_with('\'')
                 || val.starts_with('"') && val.ends_with('"')
             {
@@ -668,15 +666,15 @@ struct Help {
     print_version: bool,
 }
 
-const DEFAULT_TERM_SIZE: usize = 80;
+const MAX_TERM_WIDTH: usize = 100;
 
 impl Help {
     fn long() -> Self {
-        Self { long: true, term_size: DEFAULT_TERM_SIZE, print_version: true }
+        Self { long: true, term_size: MAX_TERM_WIDTH, print_version: true }
     }
 
     fn short() -> Self {
-        Self { long: false, term_size: DEFAULT_TERM_SIZE, print_version: true }
+        Self { long: false, term_size: MAX_TERM_WIDTH, print_version: true }
     }
 }
 
@@ -931,19 +929,19 @@ mod tests {
 
     #[test]
     fn long_help() {
-        let actual = Help { long: true, term_size: 200, print_version: false }.to_string();
+        let actual = Help { print_version: false, ..Help::long() }.to_string();
         assert_diff("tests/long-help.txt", actual);
     }
 
     #[test]
     fn short_help() {
-        let actual = Help { long: false, term_size: 200, print_version: false }.to_string();
+        let actual = Help { print_version: false, ..Help::short() }.to_string();
         assert_diff("tests/short-help.txt", actual);
     }
 
     #[test]
     fn update_readme() -> Result<()> {
-        let new = Help { long: true, term_size: 80, print_version: false }.to_string();
+        let new = Help { print_version: false, ..Help::long() }.to_string();
         let path = &Path::new(env!("CARGO_MANIFEST_DIR")).join("README.md");
         let base = fs::read_to_string(path)?;
         let mut out = String::with_capacity(base.capacity());
