@@ -186,8 +186,12 @@ impl<'a> ProcessBuilder<'a> {
     /// Executes a process, captures its stdio output, returning the captured
     /// standard output as a `String`.
     pub(crate) fn read(&mut self) -> Result<String> {
-        String::from_utf8(self.run_with_output()?.stdout)
-            .with_context(|| format!("failed to parse output of {}", self))
+        let mut output = String::from_utf8(self.run_with_output()?.stdout)
+            .with_context(|| format!("failed to parse output from {}", self))?;
+        while output.ends_with('\n') || output.ends_with('\r') {
+            output.pop();
+        }
+        Ok(output)
     }
 
     fn build(&self) -> Command {
@@ -266,14 +270,6 @@ impl fmt::Display for ProcessBuilder<'_> {
 struct ProcessError {
     /// A detailed description to show to the user why the process failed.
     desc: String,
-    /// The exit status of the process.
-    ///
-    /// This can be `None` if the process failed to launch (like process not found).
-    status: Option<ExitStatus>,
-    /// The output from the process.
-    ///
-    /// This can be `None` if the process failed to launch, or the output was not captured.
-    output: Option<Output>,
 }
 
 impl ProcessError {
@@ -305,7 +301,7 @@ impl ProcessError {
             }
         }
 
-        Self { desc, status, output: output.cloned() }
+        Self { desc }
     }
 }
 
